@@ -132,7 +132,7 @@ class ContainerMap:
         blob_client = self.container_client.get_blob_client(self.MAP_FILE_NAME)
         self.delete_map()
         blob_client.upload_blob(data=json_content)
-        self.logger(f"Finished writing map to storage account {self.CONTAINER_NAME} at {self.MAP_FILE_NAME}")
+        self.logger.info(f"Finished writing map to storage account {self.CONTAINER_NAME} at {self.MAP_FILE_NAME}")
 
     def write_map_local(self, map):
         """Creates a local copy of the storage container map
@@ -144,7 +144,7 @@ class ContainerMap:
         json_file = open(self.MAP_FILE_NAME, "w")
         json_file.write(json_content)
         json_file.close()
-        self.logger(f"Finished writing at {os.path.abspath(self.MAP_FILE_NAME)}")
+        self.logger.info(f"Finished writing at {os.path.abspath(self.MAP_FILE_NAME)}")
 
     def delete_map(self):
         """Deletes the storage map from the blob storage container if it exists
@@ -425,4 +425,4 @@ class MapReporter:
         file = open(self.OUTPUT_FILE_NAME, "w")
         file.write(file.write(csv_data))
         file.close()
-        self.logger(f"Finished writing at {os.path.abspath(self.OUTPUT_FILE_NAME)}")
+        self.logger.info(f"Finished writing at {os.path.abspath(self.OUTPUT_FILE_NAME)}")
